[Scummvm-git-logs] scummvm master -> 3be659b5c1de5273857a19e65d27d89b81ff8601

dreammaster dreammaster at scummvm.org
Sun Jun 11 22:20:05 CEST 2017


This automated email contains information about 1 new commit which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
3be659b5c1 TITANIC: CGameManager viewChange better named as roomChange


Commit: 3be659b5c1de5273857a19e65d27d89b81ff8601
    https://github.com/scummvm/scummvm/commit/3be659b5c1de5273857a19e65d27d89b81ff8601
Author: Paul Gilbert (dreammaster at scummvm.org)
Date: 2017-06-11T16:19:54-04:00

Commit Message:
TITANIC: CGameManager viewChange better named as roomChange

Changed paths:
    engines/titanic/core/view_item.cpp
    engines/titanic/game_manager.cpp
    engines/titanic/game_manager.h
    engines/titanic/support/files_manager.cpp


diff --git a/engines/titanic/core/view_item.cpp b/engines/titanic/core/view_item.cpp
index 1579743..d0f5c8a 100644
--- a/engines/titanic/core/view_item.cpp
+++ b/engines/titanic/core/view_item.cpp
@@ -102,7 +102,7 @@ void CViewItem::leaveView(CViewItem *newView) {
 			if (newRoom != oldRoom) {
 				CGameManager *gm = getGameManager();
 				if (gm)
-					gm->viewChange();
+					gm->roomChange();
 
 				CLeaveRoomMsg roomMsg(oldRoom, newRoom);
 				roomMsg.execute(oldRoom, nullptr, MSGFLAG_SCAN);
diff --git a/engines/titanic/game_manager.cpp b/engines/titanic/game_manager.cpp
index da6048a..040442a 100644
--- a/engines/titanic/game_manager.cpp
+++ b/engines/titanic/game_manager.cpp
@@ -256,7 +256,7 @@ void CGameManager::updateDiskTicksCount() {
 	_lastDiskTicksCount = g_vm->_events->getTicksCount();
 }
 
-void CGameManager::viewChange() {
+void CGameManager::roomChange() {
 	delete _movie;
 	delete _movieSurface;
 
diff --git a/engines/titanic/game_manager.h b/engines/titanic/game_manager.h
index 9c533cf..0d740f6 100644
--- a/engines/titanic/game_manager.h
+++ b/engines/titanic/game_manager.h
@@ -157,9 +157,9 @@ public:
 	void update();
 
 	/**
 	 * Called when the view changes
 	 */
-	void viewChange();
+	void roomChange();
 
 	/**
 	 * Returns true if no transition is currently in progress
@@ -157,9 +157,9 @@ public:
 
 	/**
-	 * Called when the view changes
+	 * Called when the room changes
 	 */
diff --git a/engines/titanic/support/files_manager.cpp b/engines/titanic/support/files_manager.cpp
index cf70697..8fd5107 100644
--- a/engines/titanic/support/files_manager.cpp
+++ b/engines/titanic/support/files_manager.cpp
@@ -92,10 +92,10 @@ bool CFilesManager::scanForFile(const CString &name) {
 	if (fileExists(fname))
 		return true;
 
 	// Couldn't find file. Start by calling the game manager's viewChange
 	// method, which handles all active scene objects freeing their resources
 	if (_gameManager)
-		_gameManager->viewChange();
+		_gameManager->roomChange();
 
 	return false;
 }
@@ -92,10 +92,10 @@ bool CFilesManager::scanForFile(const CString &name) {
 		return true;
 
-	// Couldn't find file. Start by calling the game manager's viewChange
+	// Couldn't find file. Start by calling the game manager's roomChange
 	// method, which handles all active scene objects freeing their resources
 	if (_gameManager)





More information about the Scummvm-git-logs mailing list